abacusai.model_monitor_summary — AbacusAI documentation

# `abacusai.model_monitor_summary`

## Module Contents

### Classes

`ModelMonitorSummary` | A summary of model monitor

class abacusai.model_monitor_summary.ModelMonitorSummary(client, modelAccuracy=None, modelDrift=None, dataIntegrity=None, biasViolations=None, alerts=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A summary of model monitor

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - modelAccuracy (list) – A list of model accuracy objects including accuracy and monitor version information.

    - modelDrift (list) – A list of model drift objects including label and prediction drifts and monitor version information.

    - dataIntegrity (list) – A list of data integrity objects including counts of violations and monitor version information.

    - biasViolations (list) – A list of bias objects including bias counts and monitor version information.

    - alerts (list) – A list of alerts by type for each model monitor instance

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict